#[non_exhaustive]
pub enum Event { Capabilities { capabilities: WEnum<GroupCapabilities>, }, OutputEnter { output: WlOutput, }, OutputLeave { output: WlOutput, }, WorkspaceEnter { workspace: ExtWorkspaceHandleV1, }, WorkspaceLeave { workspace: ExtWorkspaceHandleV1, }, Removed, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Capabilities

compositor capabilities

This event advertises the capabilities supported by the compositor. If a capability isn’t supported, clients should hide or disable the UI elements that expose this functionality. For instance, if the compositor doesn’t advertise support for creating workspaces, a button triggering the create_workspace request should not be displayed.

The compositor will ignore requests it doesn’t support. For instance, a compositor which doesn’t advertise support for creating workspaces will ignore create_workspace requests.

Compositors must send this event once after creation of an ext_workspace_group_handle_v1. When the capabilities change, compositors must send this event again.

Fields

capabilities: WEnum<GroupCapabilities>

capabilities



OutputEnter

output assigned to workspace group

This event is emitted whenever an output is assigned to the workspace group or a new wl_output object is bound by the client, which was already assigned to this workspace_group.

Fields

output: WlOutput


OutputLeave

output removed from workspace group

This event is emitted whenever an output is removed from the workspace group.

Fields

output: WlOutput


WorkspaceEnter

workspace added to workspace group

This event is emitted whenever a workspace is assigned to this group. A workspace may only ever be assigned to a single group at a single point in time, but can be re-assigned during it’s lifetime.

Fields



WorkspaceLeave

workspace removed from workspace group

This event is emitted whenever a workspace is removed from this group.

Fields



Removed

this workspace group has been removed

This event is send when the group associated with the ext_workspace_group_handle_v1 has been removed. After sending this request the compositor will immediately consider the object inert. Any requests will be ignored except the destroy request. It is guaranteed there won’t be any more events referencing this ext_workspace_group_handle_v1.

The compositor must remove all workspaces belonging to a workspace group via a workspace_leave event before removing the workspace group.

Implementations



impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message