Struct ExtWorkspaceGroupHandleV1

pub struct ExtWorkspaceGroupHandleV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
a workspace group assigned to a set of outputs

A ext_workspace_group_handle_v1 object represents a workspace group that is assigned a set of outputs and contains a number of workspaces.

The set of outputs assigned to the workspace group is conveyed to the client via output_enter and output_leave events, and its workspaces are conveyed with workspace events.

For example, a compositor which has a set of workspaces for each output may advertise a workspace group (and its workspaces) per output, whereas a compositor where a workspace spans all outputs may advertise a single workspace group for all outputs.

See also the Event enum for this interface.

Implementations



impl ExtWorkspaceGroupHandleV1

pub fn create_workspace(&self, workspace: String)

create a new workspace

Request that the compositor create a new workspace with the given name and assign it to this group.

There is no guarantee that the compositor will create a new workspace, or that the created workspace will have the provided name.

pub fn destroy(&self)

destroy the ext_workspace_group_handle_v1 object

Destroys the ext_workspace_group_handle_v1 object.

This request should be send either when the client does not want to use the workspace group object any more or after the removed event to finalize the destruction of the object.